@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.time.c,v 3.20 1998/11/24 18:17:38 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.time.c,v 3.22 2000/06/10 21:35:41 kim Exp $ */
 /*
  * sh.time.c: Shell time keeping and printing.
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.time.c,v 3.20 1998/11/24 18:17:38 christos Exp $")
+RCSID("$Id: sh.time.c,v 3.22 2000/06/10 21:35:41 kim Exp $")
 
 #ifdef SUNOS4
 # include <machine/param.h>
@@ -86,10 +86,11 @@ settimes()
     (void) get_process_stats(&time0, PS_SELF, &ru0, &ruch);
     ruadd(&ru0,	&ruch);
 # else	/* _SEQUENT_ */
+    seconds0 = time(NULL);
 #  ifndef COHERENT
     time0 = times(&times0);
 #  else	/* !COHERENT */
-    time0 = HZ * time(NULL);
+    time0 = HZ * seconds0;
     times(&times0);
 #  endif /* !COHERENT */
     times0.tms_stime +=	times0.tms_cstime;
@@ -454,9 +455,9 @@ prusage(bs, es,	e, b)
 		if ((sysinfo.cpu_count == 0) &&
 		    (getsysinfo(SYSINFO_SIZE, &sysinfo)	< 0))
 		    sysinfo.cpu_count =	1;
-		    i =	(ms == 0) ? 0 :	(t * 1000 / (ms	* sysinfo.cpu_count));
+		    i =	(ms == 0) ? 0 :	(t * 1000.0 / (ms * sysinfo.cpu_count));
 #else /* convex	*/
-		i = (ms	== 0) ?	0 : (t * 1000 /	ms);
+		i = (ms	== 0) ?	0 : (long)(t * 1000.0 / ms);
 #endif /* convex */
 		xprintf("%ld.%01ld%%", i / 10, i % 10);	/* nn.n% */
 		break;
